@@ -15,7 +15,7 @@
 
 import argparse
 from datetime import datetime
-import mock
+from unittest import mock
 
 from blazarclient import exception
 from blazarclient import shell
@@ -28,7 +28,7 @@ FIRST_LEASE = 'd1e43d6d-8f6f-4c2e-b0a9-2982b39dc698'
 SECOND_LEASE = '424d21c3-45a2-448a-81ad-32eddc888375'
 
 
-@mock.patch('blazarclient.v1.shell_commands.leases._utc_now', mock_time)
+@mock.patch('oslo_utils.timeutils.utcnow', mock_time)
 class CreateLeaseTestCase(tests.TestCase):
 
     def setUp(self):
@@ -328,7 +328,6 @@ class ShowLeaseTestCase(tests.TestCase):
     def test_show_lease(self):
         show_lease, lease_manager = self.create_show_command()
         lease_manager.get.return_value = {'id': FIRST_LEASE}
-        mock.seal(lease_manager)
 
         args = argparse.Namespace(id=FIRST_LEASE)
         expected = [('id',), (FIRST_LEASE,)]
@@ -343,7 +342,6 @@ class ShowLeaseTestCase(tests.TestCase):
             {'id': SECOND_LEASE, 'name': 'second-lease'},
         ]
         lease_manager.get.return_value = {'id': SECOND_LEASE}
-        mock.seal(lease_manager)
 
         args = argparse.Namespace(id='second-lease')
         expected = [('id',), (SECOND_LEASE,)]
@@ -368,7 +366,6 @@ class DeleteLeaseTestCase(tests.TestCase):
     def test_delete_lease(self):
         delete_lease, lease_manager = self.create_delete_command()
         lease_manager.delete.return_value = None
-        mock.seal(lease_manager)
 
         args = argparse.Namespace(id=FIRST_LEASE)
         delete_lease.run(args)
@@ -382,7 +379,6 @@ class DeleteLeaseTestCase(tests.TestCase):
             {'id': SECOND_LEASE, 'name': 'second-lease'},
         ]
         lease_manager.delete.return_value = None
-        mock.seal(lease_manager)
 
         args = argparse.Namespace(id='second-lease')
         delete_lease.run(args)
